Module gaussian_integer

Module gaussian_integer 

GaussianInteger, a type representing complex numbers whose real and imaginary parts are both integers.

Modules

arithmetic
Traits for arithmetic.
comparison
Comparison of ComparableGaussianIntegers and ComparableGaussianIntegerRefs.
conversion
Functions for converting a GaussianInteger to and from other types and strings.
exhaustive
Iterators that generate GaussianIntegers without repetition.
factorization
Functions for the factorization of GaussianIntegers.
logic
Traits for logic and bit manipulation.
random
Iterators that generate GaussianIntegers randomly.

Structs

ComparableGaussianInteger
ComparableGaussianInteger is a wrapper around a GaussianInteger, taking the GaussianInteger by value.
ComparableGaussianIntegerRef
ComparableGaussianIntegerRef is a wrapper around a GaussianInteger, taking the GaussianInteger by reference.
GaussianInteger
A Gaussian integer: a complex number whose real and imaginary parts are both integers.